@@ -1,20 +1,30 @@
 use core::iter::FromIterator;
-use std::ops::ControlFlow;
+use std::pin::Pin;
 
 use crate::{error::StdSyncSendError, Bus, Message};
 use async_trait::async_trait;
+use futures::Stream;
 
-#[async_trait]
-pub trait AsyncProducer<'a, M: Message>: Send {
-    type Error: StdSyncSendError;
-    type Context: Send + 'a;
-    type Response: Message;
-
-    async fn start(&'a self, msg: M, bus: &Bus) -> Result<Self::Context, Self::Error>;
-    async fn next(&'a self, ctx: &mut Self::Context, bus: &Bus) -> Result<ControlFlow<Self::Response>, Self::Error>;
-    async fn finish(&'a self, _ctx: Self::Context, _bus: &Bus) -> Result<(), Self::Error>;
+#[derive(Debug, Clone, Copy)]
+pub struct ProducerStats {
+    pub completed: usize,
+    pub failed: usize,
 }
 
+#[async_trait]
+pub trait AsyncProducer<M: Message>: Send + Sync {
+    type Item: Message;
+    type Response: Message;
+    type Error: StdSyncSendError;
+
+    async fn producer(
+        &self,
+        msg: M,
+        bus: &Bus,
+    ) -> Result<Pin<Box<dyn Stream<Item = Result<Self::Item, Self::Error>> + Send + '_>>, Self::Error>;
+
+    async fn finish(&self, stats: ProducerStats, bus: &Bus) -> Result<Self::Response, Self::Error>;
+}
 
 pub trait Handler<M: Message>: Send + Sync {
     type Error: StdSyncSendError;
